==> mapr-apiserver-6.0.0-mapr.jar: org/apache/drill/exec/rpc/user/clusterclient/DrillConnection.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.drill.exec.rpc.user.clusterclient;

import org.apache.drill.common.exceptions.DrillIOException;
import org.apache.drill.exec.memory.BufferAllocator;

import java.io.Closeable;
import java.util.Properties;

public interface DrillConnection extends AutoCloseable {

  /**
   * Gets the {@link BufferAllocator buffer allocator} used by this connection.
   *
   * @return buffer allocator
   */
  BufferAllocator getAllocator();

  /**
   * Establish a new session over this connection based on the properties.
   *
   * @param properties properties
   * @return new drill session
   * @throws DrillIOException in case of error
   */
  DrillSession newSession(Properties properties) throws DrillIOException;

  /**
   * Release resources, and close all {@link DrillSession sessions} created
   * over this connection.
   **/
  //void close();

}

==> mapr-apiserver-6.1.0-mapr.jar: org/apache/drill/exec/rpc/user/clusterclient/DrillConnection.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.drill.exec.rpc.user.clusterclient;

import org.apache.drill.common.exceptions.DrillIOException;
import org.apache.drill.exec.memory.BufferAllocator;

import java.io.Closeable;
import java.util.Properties;

public interface DrillConnection {

  /**
   * Gets the {@link BufferAllocator buffer allocator} used by this connection.
   *
   * @return buffer allocator
   */
  BufferAllocator getAllocator();

  /**
   * Establish a new session over this connection based on the properties.
   *
   * @param properties properties
   * @return new drill session
   * @throws DrillIOException in case of error
   */
  DrillSession newSession(Properties properties) throws DrillIOException;

  /**
   * Release resources, and close all {@link DrillSession sessions} created
   * over this connection.
   **/
  void close();

}
